SWDEV-503089 - Fix and enable disabled HIP tests from math group (#1319)
* SWDEV-503089 - Fix and enable disabled HIP tests from math group * SWDEV-503089 - Move single precision reduced run to a common function
This commit is contained in:
@@ -123,9 +123,9 @@ class Dummy {
|
||||
__device__ ~Dummy() {}
|
||||
};
|
||||
__global__ void fdividef_kernel_v1(float* x, float y) { float result = fdividef(x, y); }
|
||||
__global__ void fdividef_kernel_v2(Dummy x, float y) { float result = fdivide(x); }
|
||||
__global__ void fdividef_kernel_v3(float x, float* y) { float result = fdivide(x); }
|
||||
__global__ void fdividef_kernel_v4(float x, Dummy y) { float result = fdivide(x); }
|
||||
__global__ void fdividef_kernel_v2(Dummy x, float y) { float result = fdividef(x, y); }
|
||||
__global__ void fdividef_kernel_v3(float x, float* y) { float result = fdividef(x, y); }
|
||||
__global__ void fdividef_kernel_v4(float x, Dummy y) { float result = fdividef(x, y); }
|
||||
)"};
|
||||
|
||||
static constexpr auto kIsFinite{R"(
|
||||
|
||||
Reference in New Issue
Block a user